import { useContext } from 'react';
import LocaleContext from './private/LocaleContext.js';
/**
 * This hook uses the `LocaleContext` to return the locale data.
 * @example Use it with a default context
 * ```js
 * const { locale } = useLocale();
 * assertEqual(locale, 'en-GB');
 * ```
 * @example Use with a Provider
 * ```js
 * <LocaleContextProvider locale="nl-NL">
 *   ...
 *   const { locale } = useLocale();
 *   assertEqual(locale, 'nl-NL');
 *   ...
 * </LocaleContextProvider>
 * ```
 */

function useLocale() {
  return useContext(LocaleContext);
}

export { useLocale as default, useLocale };
//# sourceMappingURL=useLocale.js.map
